package net.wanji.opt.controllerv2.report;

import com.alibaba.fastjson.JSONObject;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.controllerv2.report.design.CrossRidLaneInfoResult;
import net.wanji.opt.controllerv2.report.design.GreenWaveOptimizeAnalysisResult;
import net.wanji.opt.servicev2.report.CrossRidLaneService;
import net.wanji.opt.vo2.report.CrossRidLaneResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
@Slf4j
@RequestMapping("/cross-rid-lane")
@Api(value="CrossRidLaneController", description="路口分析报告接口", tags = "路口分析报告-周报")
public class CrossRidLaneController {

    @Autowired
    private CrossRidLaneService crossRidLaneService;

    @ApiOperation(httpMethod="GET",value="1.1-路口基础信息", notes="")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossIds", value = "路口ID,多个id用','分隔", required = true, dataType = "String",defaultValue = "13NEJ0B5R80,13N650B5P30"),
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossRidLaneInfoResult.class),
    })
    @GetMapping(value = "/getCrossInfoList")
    public JsonViewObject getCrossInfoList(@RequestParam(value = "crossIds", required = false) String crossIds) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try {
            List<CrossRidLaneResult> object = crossRidLaneService.getCrossInfoList(crossIds);
            jsonViewObject.success(object);
        } catch (Exception e) {
            jsonViewObject.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonViewObject;
    }
}
