package net.wanji.opt.controllerv2.report;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.controllerv2.report.design.GreenReportProblemDetailAnalysis;
import net.wanji.opt.controllerv2.report.design.GreenReportProblemOverallAnalysis;
import net.wanji.opt.controllerv2.report.design.GreenWaveOptimizeAnalysisResult;
import net.wanji.opt.controllerv2.report.design.ImportGreenReportAnalysis;
import net.wanji.opt.controllerv2.report.vo.GreenWaveOptimizeAnalysisResultResponseDTO;
import net.wanji.opt.controllerv2.report.vo.ImportGreenReportAnalysisResponseVO;
import net.wanji.opt.servicev2.report.AnalysisGreenWaveOptimizeWeekService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * <p>
 * 干线概况 接口API
 * </p>
 *  @version 1.0
 * @author
 * @Date 2025-03-18
 */
@RestController
@Slf4j
@RequestMapping("/green-wave-optimize")
@Api(value="GreenWaveOptimizeAnalysisController", description="干线分析报告接口", tags = "干线分析报告-周报")
public class GreenWaveOptimizeAnalysisController {

    @Autowired
    private AnalysisGreenWaveOptimizeWeekService analysisGreenWaveOptimizeWeekService;

    @ApiOperation(httpMethod="GET",value="5.1-干线优化-总体分析", notes="")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ids", value = "干线ID,多个id用','分隔【为空时查询所有干线】", required = false, dataType = "String",defaultValue = "1,2"),
            @ApiImplicitParam(name = "year", value = "年份", required = true, dataType = "String",defaultValue = "2025"),
            @ApiImplicitParam(name = "week", value = "一年的第几周", required = true, dataType = "String",defaultValue = "14"),
            })
    @GetMapping(value = "/getTotalityData")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenWaveOptimizeAnalysisResult.class),
    })
    public JsonViewObject getTotalityData(Integer year,Integer week,@RequestParam(required = false) String ids) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try {
            GreenWaveOptimizeAnalysisResultResponseDTO totalityData = analysisGreenWaveOptimizeWeekService.getTotalityData(year, week, ids);
            jsonViewObject.success(totalityData);
        } catch (Exception e) {
            jsonViewObject.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonViewObject;
    }

    @ApiOperation(httpMethod="GET",value="5.2-重点干线优化分析", notes="")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ids", value = "干线ID,多个id用','分隔【为空时查询所有干线】", required = false, dataType = "String",defaultValue = "1,2"),
            @ApiImplicitParam(name = "year", value = "年份", required = true, dataType = "String",defaultValue = "2025"),
            @ApiImplicitParam(name = "week", value = "一年的第几周", required = true, dataType = "String",defaultValue = "14"),
    })
    @GetMapping(value = "/getProblemDetail")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = ImportGreenReportAnalysis.class),
    })
    public JsonViewObject getProblemDetail(Integer year,Integer week,@RequestParam(required = false) String ids) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        try {
            List<ImportGreenReportAnalysisResponseVO> problemDetail = analysisGreenWaveOptimizeWeekService.getProblemDetail(year, week, ids);
            jsonViewObject.success(problemDetail);
        } catch (Exception e) {
            jsonViewObject.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
        return jsonViewObject;
    }
}
